==> manaplus_1.6.2.13.orig.tar.xz: manaplus-1.6.2.13/src/resources/mapreader.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2016  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef RESOURCES_MAPREADER_H
#define RESOURCES_MAPREADER_H

#include "utils/xml.h"

#include "resources/map/maplayer.h"

class Map;
class MapHeights;
class MapLayer;
class Properties;
class Tileset;

/**
 * Reader for XML map files (*.tmx)
 */
class MapReader final
{
    public:
        /**
         * Read an XML map from a file.
         */
        static Map *readMap(const std::string &restrict filename,
                            const std::string &restrict realFilename)
                            A_WARN_UNUSED;

        /**
         * Read an XML map from a parsed XML tree. The path is used to find the
         * location of referenced tileset images.
         */
        static Map *readMap(XmlNodePtrConst node,
                            const std::string &path) A_WARN_UNUSED;

        static Map *createEmptyMap(const std::string &restrict filename,
                                   const std::string &restrict realFilename)
                                   A_WARN_UNUSED;

        /**
         * Reads a map layer and adds it to the given map.
         */
        static void readLayer(const XmlNodePtr node, Map *const map);

    private:
        /**
         * Reads the properties element.
         *
         * @param node  The <code>properties</code> element.
         * @param props The Properties instance to which the properties will
         *              be assigned.
         */
        static void readProperties(const XmlNodePtrConst node,
                                   Properties *const props);

        static bool readBase64Layer(const XmlNodePtrConst childNode,
                                    Map *const map,
                                    MapLayer *const layer,
                                    const MapLayer::Type &layerType,
                                    MapHeights *const heights,
                                    const std::string &compression,
                                    int &restrict x, int &restrict y,
                                    const int w, const int h);

        static bool readCsvLayer(const XmlNodePtrConst childNode,
                                 Map *const map,
                                 MapLayer *const layer,
                                 const MapLayer::Type &layerType,
                                 MapHeights *const heights,
                                 int &restrict x, int &restrict y,
                                 const int w, const int h);

        /**
         * Reads a tile set.
         */
        static Tileset *readTileset(XmlNodePtr node,
                                    const std::string &path,
                                    Map *const map) A_WARN_UNUSED;

        static void updateMusic(Map *const map);

        static void addLayerToList(const std::string &fileName);

        static void loadLayers(const std::string &path);

        static void unloadTempLayers();
};

#endif  // RESOURCES_MAPREADER_H

==> manaplus_1.6.5.7.orig.tar.xz: manaplus-1.6.5.7/src/resources/mapreader.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2016  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef RESOURCES_MAPREADER_H
#define RESOURCES_MAPREADER_H

#include "utils/xml.h"

#include "resources/map/maplayer.h"

class Map;
class MapHeights;
class Properties;
class Tileset;

/**
 * Reader for XML map files (*.tmx)
 */
class MapReader final
{
    public:
        /**
         * Read an XML map from a file.
         */
        static Map *readMap(const std::string &restrict filename,
                            const std::string &restrict realFilename)
                            A_WARN_UNUSED;

        /**
         * Read an XML map from a parsed XML tree. The path is used to find the
         * location of referenced tileset images.
         */
        static Map *readMap(XmlNodePtrConst node,
                            const std::string &path) A_WARN_UNUSED;

        static Map *createEmptyMap(const std::string &restrict filename,
                                   const std::string &restrict realFilename)
                                   A_WARN_UNUSED;

        /**
         * Reads a map layer and adds it to the given map.
         */
        static void readLayer(const XmlNodePtr node,
                              Map *const map) A_NONNULL(2);

    private:
        /**
         * Reads the properties element.
         *
         * @param node  The <code>properties</code> element.
         * @param props The Properties instance to which the properties will
         *              be assigned.
         */
        static void readProperties(const XmlNodePtrConst node,
                                   Properties *const props) A_NONNULL(2);

        static bool readBase64Layer(const XmlNodePtrConst childNode,
                                    Map *const map,
                                    MapLayer *const layer,
                                    const MapLayer::Type &layerType,
                                    MapHeights *const heights,
                                    const std::string &compression,
                                    int &restrict x, int &restrict y,
                                    const int w, const int h) A_NONNULL(2);

        static bool readCsvLayer(const XmlNodePtrConst childNode,
                                 Map *const map,
                                 MapLayer *const layer,
                                 const MapLayer::Type &layerType,
                                 MapHeights *const heights,
                                 int &restrict x, int &restrict y,
                                 const int w, const int h) A_NONNULL(2);

        /**
         * Reads a tile set.
         */
        static Tileset *readTileset(XmlNodePtr node,
                                    const std::string &path,
                                    Map *const map) A_WARN_UNUSED A_NONNULL(3);

        static void updateMusic(Map *const map) A_NONNULL(1);

        static void addLayerToList(const std::string &fileName);

        static void loadLayers(const std::string &path);

        static void unloadTempLayers();
};

#endif  // RESOURCES_MAPREADER_H
